Struct rkyv::collections::index_set::ArchivedIndexSet [−][src]
#[repr(transparent)]pub struct ArchivedIndexSet<K> { /* fields omitted */ }Expand description
An archived IndexSet.
Implementations
Returns whether a key is present in the hash set.
Returns the value stored in the set, if any.
Returns the item index and value stored in the set, if any.
Returns the index of a key if it exists in the set.
Gets the hasher for this index set.
Returns an iterator over the keys of the index set in order.
pub unsafe fn resolve_from_len(
len: usize,
pos: usize,
resolver: IndexSetResolver,
out: *mut Self
)
pub unsafe fn resolve_from_len(
len: usize,
pos: usize,
resolver: IndexSetResolver,
out: *mut Self
)
Resolves an archived index map from a given length and parameters.
Safety
lenmust be the number of elements that were serializedposmust be the position ofoutwithin the archiveresolvermust be the result of serializing a hash map